@@ -52,38 +52,47 @@ template< typename Type_, int SizeRows_ = UnknownSize, int SizeCols_ = UnknownSi
 template< typename Type_, int SizeRows_ = UnknownSize, int SizeCols_ = UnknownSize> class UpperTriangular;
 template< typename Type_, int SizeRows_ = UnknownSize, int SizeCols_ = UnknownSize> class LowerTriangular;
 
-typedef Vector<Real, UnknownSize> VectorX;
-typedef Vector<Real, 3> Vector3;
-typedef Vector<Real, 2> Vector2;
+typedef Vector<Real, UnknownSize>   VectorX;
+typedef Vector<Real, 3>             Vector3;
+typedef Vector<Real, 2>             Vector2;
 typedef Vector<double, UnknownSize> VectorXd;
-typedef Vector<double, 3> Vector3d;
-typedef Vector<double, 2> Vector2d;
-typedef Vector<int, UnknownSize> VectorXi;
-typedef Vector<int, 3> Vector3i;
-typedef Vector<int, 2> Vector2i;
+typedef Vector<double, 3>           Vector3d;
+typedef Vector<double, 2>           Vector2d;
+typedef Vector<int, UnknownSize>    VectorXi;
+typedef Vector<int, 3>              Vector3i;
+typedef Vector<int, 2>              Vector2i;
 
-typedef Point<Real, UnknownSize> PointX;
-typedef Point<Real, 3> ConstPoint3;
-typedef Point<Real, 2> ConstPoint2;
-typedef Point<double, UnknownSize> PointXd;
-typedef Point<double, 3> ConstPoint3d;
-typedef Point<double, 2> ConstPoint2d;
-typedef Point<int, UnknownSize> PointXi;
-typedef Point<int, 3> ConstPoint3i;
-typedef Point<int, 2> ConstPoint2i;
+typedef Vector<Real, UnknownSize>   ConstVectorX;
+typedef Vector<Real, 3>             ConstVector3;
+typedef Vector<Real, 2>             ConstVector2;
+typedef Vector<double, UnknownSize> ConstVectorXd;
+typedef Vector<double, 3>           ConstVector3d;
+typedef Vector<double, 2>           ConstVector2d;
+typedef Vector<int, UnknownSize>    ConstVectorXi;
+typedef Vector<int, 3>              ConstVector3i;
+typedef Vector<int, 2>              ConstVector2i;
 
-typedef Point<Real, UnknownSize> PointX;
-typedef Point<Real, 3> ConstPoint3;
-typedef Point<Real, 2> ConstPoint2;
+typedef Point<Real, UnknownSize>   PointX;
+typedef Point<Real, 3>             Point3;
+typedef Point<Real, 2>             Point2;
 typedef Point<double, UnknownSize> PointXd;
-typedef Point<double, 3> ConstPoint3d;
-typedef Point<double, 2> ConstPoint2d;
-typedef Point<int, UnknownSize> PointXi;
-typedef Point<int, 3> ConstPoint3i;
-typedef Point<int, 2> ConstPoint2i;
+typedef Point<double, 3>           Point3d;
+typedef Point<double, 2>           Point2d;
+typedef Point<int, UnknownSize>    PointXi;
+typedef Point<int, 3>              Point3i;
+typedef Point<int, 2>              Point2i;
+
+typedef Point<Real, UnknownSize>   ConstPointX;
+typedef Point<Real, 3>             ConstPoint3;
+typedef Point<Real, 2>             ConstPoint2;
+typedef Point<double, UnknownSize> ConstPointXd;
+typedef Point<double, 3>           ConstPoint3d;
+typedef Point<double, 2>           ConstPoint2d;
+typedef Point<int, UnknownSize>    ConstPointXi;
+typedef Point<int, 3>              ConstPoint3i;
+typedef Point<int, 2>              ConstPoint2i;
 }
 
-
 namespace hidden
 {
 /** @ingroup hidden
@@ -97,12 +106,13 @@ struct Traits< Const::Identity <Type_, Size_> >
     structure_ = Arrays::diagonal_,
     sizeRows_  = Size_,
     sizeCols_  = Size_,
+    size_      = Size_,
     orient_    = Arrays::by_col_,
     storage_   = Arrays::sparse_
   };
 
   typedef Type_                Type;
-  typedef typename RemoveConst<Type>::Type ConstReturnType;
+  typedef typename RemoveConst<Type>::Type TypeConst;
 };
 /** @ingroup hidden
  *  @brief Traits class for the identity constant matrix
@@ -115,11 +125,12 @@ struct Traits< Const::Vector <Type_, Size_> >
     structure_ = Arrays::vector_,
     sizeRows_  = Size_,
     sizeCols_  = 1,
+    size_      = Size_,
     orient_    = Arrays::by_col_,
     storage_   = Arrays::sparse_
   };
   typedef Type_                Type;
-  typedef typename RemoveConst<Type>::Type ConstReturnType;
+  typedef typename RemoveConst<Type>::Type TypeConst;
 };
 /** @ingroup hidden
  *  @brief Traits class for the constant vector_
@@ -132,11 +143,12 @@ struct Traits< Const::Point <Type_, Size_> >
     structure_ = Arrays::point_,
     sizeRows_  = 1,
     sizeCols_  = Size_,
+    size_      = Size_,
     orient_    = Arrays::by_row_,
     storage_   = Arrays::sparse_
   };
   typedef Type_                Type;
-  typedef typename RemoveConst<Type>::Type ConstReturnType;
+  typedef typename RemoveConst<Type>::Type TypeConst;
 };
 /** @ingroup hidden
  *  @brief Traits class for the square constant matrix
@@ -149,11 +161,12 @@ struct Traits< Const::Square <Type_, Size_> >
     structure_ = Arrays::square_,
     sizeRows_  = Size_,
     sizeCols_  = Size_,
+    size_      = Size_,
     orient_    = Arrays::by_col_,
     storage_   = Arrays::sparse_
   };
   typedef Type_                Type;
-  typedef typename RemoveConst<Type>::Type ConstReturnType;
+  typedef typename RemoveConst<Type>::Type TypeConst;
 };
 /** @ingroup hidden
  *  @brief Traits class for the general constant matrix
@@ -170,7 +183,7 @@ struct Traits< Const::Array<Type_, SizeRows_, SizeCols_> >
     storage_   = Arrays::sparse_
   };
   typedef Type_                Type;
-  typedef typename RemoveConst<Type>::Type ConstReturnType;
+  typedef typename RemoveConst<Type>::Type TypeConst;
 };
 /** @ingroup hidden
  *  @brief Traits class for the upper triangular constant matrix
@@ -187,7 +200,7 @@ struct Traits< Const::UpperTriangular<Type_, SizeRows_, SizeCols_> >
     storage_   = Arrays::sparse_
   };
   typedef Type_                Type;
-  typedef typename RemoveConst<Type>::Type ConstReturnType;
+  typedef typename RemoveConst<Type>::Type TypeConst;
 };
 /** @ingroup hidden
  *  @brief Traits class for the lower triangular constant matrix
@@ -204,7 +217,7 @@ struct Traits< Const::LowerTriangular<Type_, SizeRows_, SizeCols_> >
     storage_   = Arrays::sparse_
   };
   typedef Type_                Type;
-  typedef typename RemoveConst<Type>::Type ConstReturnType;
+  typedef typename RemoveConst<Type>::Type TypeConst;
 };
 
 } // namespace hidden
@@ -230,7 +243,7 @@ class IConstArray: protected IContainer2D<hidden::Traits<Derived>::sizeRows_, hi
     /** Type for the IContainer2D base Class. */
     typedef IContainer2D<sizeRows_, sizeCols_ > Base2D;
     typedef ExprBase<Derived> Base;
-    typedef typename hidden::Traits< Derived >::ConstReturnType ConstReturnType;
+    typedef typename hidden::Traits< Derived >::TypeConst TypeConst;
 
   protected:
     /** default constructor */
@@ -300,7 +313,7 @@ class Identity: public IConstArray<Identity<Type_, Size_> >
   public:
     typedef IConstArray<Identity<Type_, Size_> > Base;
     typedef typename hidden::Traits< Identity<Type_, Size_> >::Type Type;
-    typedef typename hidden::Traits< Identity<Type_, Size_> >::ConstReturnType ConstReturnType;
+    typedef typename hidden::Traits< Identity<Type_, Size_> >::TypeConst TypeConst;
     enum
     {
       structure_ = hidden::Traits< Identity <Type_, Size_> >::structure_,
@@ -316,11 +329,11 @@ class Identity: public IConstArray<Identity<Type_, Size_> >
     /** @return the element (i,j) of the identity matrix.
      *  @param i,j row and column indexes
      **/
-    inline ConstReturnType elt2Impl(int i, int j) const { return (i==j ? Type(1) : Type(0));}
+    inline TypeConst elt2Impl(int i, int j) const { return (i==j ? Type(1) : Type(0));}
     /** @return the element ith element of the identity matrix
-     *  @param i index of the ith element
+     *  @param i index of the element to get
      **/
-    inline ConstReturnType elt1Impl(int i) const { return Type(1);}
+    inline TypeConst elt1Impl(int i) const { return Type(1);}
 };
 
 /**@ingroup Arrays
@@ -351,7 +364,7 @@ class Square: public IConstArray<Square<Type_, Size_> >
   public:
     typedef IConstArray<Square<Type_, Size_> > Base;
     typedef typename hidden::Traits< Square<Type_, Size_> >::Type Type;
-    typedef typename hidden::Traits< Square<Type_, Size_> >::ConstReturnType ConstReturnType;
+    typedef typename hidden::Traits< Square<Type_, Size_> >::TypeConst TypeConst;
     enum
     {
       structure_ = hidden::Traits< Square <Type_, Size_> >::structure_,
@@ -367,7 +380,7 @@ class Square: public IConstArray<Square<Type_, Size_> >
     /** @return the element (i,j) of the constant square matrix.
      *  @param i,j row and column indexes
      **/
-    inline ConstReturnType elt2Impl(int i, int j) const { return (Type(1));}
+    inline TypeConst elt2Impl(int i, int j) const { return (Type(1));}
 };
 
 /**@ingroup Arrays
@@ -399,7 +412,7 @@ class Array: public IConstArray<Array<Type_, SizeRows_, SizeCols_> >
   public:
     typedef IConstArray<Array<Type_, SizeRows_, SizeCols_> > Base;
     typedef typename hidden::Traits< Array<Type_, SizeRows_, SizeCols_> >::Type Type;
-    typedef typename hidden::Traits< Array<Type_, SizeRows_, SizeCols_> >::ConstReturnType ConstReturnType;
+    typedef typename hidden::Traits< Array<Type_, SizeRows_, SizeCols_> >::TypeConst TypeConst;
 
     enum
     {
@@ -416,7 +429,7 @@ class Array: public IConstArray<Array<Type_, SizeRows_, SizeCols_> >
     /** @return the element (i,j) of the constant square matrix.
      *  @param i,j row and column indexes
      **/
-    inline ConstReturnType elt2Impl(int i, int j) const { return (Type(1));}
+    inline TypeConst elt2Impl(int i, int j) const { return (Type(1));}
 };
 
 /**@ingroup Arrays
@@ -448,7 +461,7 @@ class UpperTriangular: public IConstArray<UpperTriangular<Type_, SizeRows_, Size
   public:
     typedef IConstArray<UpperTriangular<Type_, SizeRows_, SizeCols_> > Base;
     typedef typename hidden::Traits< UpperTriangular<Type_, SizeRows_, SizeCols_> >::Type Type;
-    typedef typename hidden::Traits< UpperTriangular<Type_, SizeRows_, SizeCols_> >::ConstReturnType ConstReturnType;
+    typedef typename hidden::Traits< UpperTriangular<Type_, SizeRows_, SizeCols_> >::TypeConst TypeConst;
 
     enum
     {
@@ -465,7 +478,7 @@ class UpperTriangular: public IConstArray<UpperTriangular<Type_, SizeRows_, Size
     /** @return the element (i,j) of the constant upper triangular matrix.
      *  @param i,j row and column indexes
      **/
-    inline ConstReturnType elt2Impl(int i, int j) const { return i<j ? (Type(1)) : Type(0);}
+    inline TypeConst elt2Impl(int i, int j) const { return i<j ? (Type(1)) : Type(0);}
 };
 
 /**@ingroup Arrays
@@ -497,7 +510,7 @@ class LowerTriangular: public IConstArray<LowerTriangular<Type_, SizeRows_, Size
   public:
     typedef IConstArray<LowerTriangular<Type_, SizeRows_, SizeCols_> > Base;
     typedef typename hidden::Traits< LowerTriangular<Type_, SizeRows_, SizeCols_> >::Type Type;
-    typedef typename hidden::Traits< LowerTriangular<Type_, SizeRows_, SizeCols_> >::ConstReturnType ConstReturnType;
+    typedef typename hidden::Traits< LowerTriangular<Type_, SizeRows_, SizeCols_> >::TypeConst TypeConst;
 
     enum
     {
@@ -514,7 +527,7 @@ class LowerTriangular: public IConstArray<LowerTriangular<Type_, SizeRows_, Size
     /** @return the element (i,j) of the constant lower triangular matrix.
      *  @param i,j row and column indexes
      **/
-    inline ConstReturnType elt2Impl(int i, int j) const { return (Type(1));}
+    inline TypeConst elt2Impl(int i, int j) const { return (Type(1));}
 };
 
 /**@ingroup Arrays
@@ -541,7 +554,7 @@ class Point: public IConstArray<Point<Type_, Size_> >
   public:
     typedef IConstArray<Point<Type_, Size_> > Base;
     typedef typename hidden::Traits< Point<Type_, Size_> >::Type Type;
-    typedef typename hidden::Traits< Point<Type_, Size_> >::ConstReturnType ConstReturnType;
+    typedef typename hidden::Traits< Point<Type_, Size_> >::TypeConst TypeConst;
 
     enum
     {
@@ -558,11 +571,11 @@ class Point: public IConstArray<Point<Type_, Size_> >
     /** @return the j-th element  of the constant row-vector.
      *  @param j index of the element
      **/
-    inline ConstReturnType elt1Impl(int j) const { return (Type(1));}
+    inline TypeConst elt1Impl(int j) const { return (Type(1));}
     /** @return the element (i,j) of the constant row-vector.
      *  @param i,j row and column indexes
      **/
-    inline ConstReturnType elt2Impl(int i, int j) const { return (Type(1));}
+    inline TypeConst elt2Impl(int i, int j) const { return (Type(1));}
 };
 
 /**@ingroup Arrays
@@ -589,7 +602,7 @@ class Vector: public IConstArray<Vector<Type_, Size_> >
   public:
     typedef IConstArray<Vector<Type_, Size_> > Base;
     typedef typename hidden::Traits< Vector<Type_, Size_> >::Type Type;
-    typedef typename hidden::Traits< Vector<Type_, Size_> >::ConstReturnType ConstReturnType;
+    typedef typename hidden::Traits< Vector<Type_, Size_> >::TypeConst TypeConst;
 
     enum
     {
@@ -606,11 +619,11 @@ class Vector: public IConstArray<Vector<Type_, Size_> >
     /** @return the i-th element of the constant vector.
      *  @param i index of the element
      **/
-    inline ConstReturnType elt1Impl(int i) const { return (Type(1));}
+    inline TypeConst elt1Impl(int i) const { return (Type(1));}
     /** @return the element (i,j) of the constant vector.
      *  @param i,j row and column indexes
      **/
-    inline ConstReturnType elt2Impl(int i, int j) const { return (Type(1));}
+    inline TypeConst elt2Impl(int i, int j) const { return (Type(1));}
 };
 
 
