@@ -37,7 +37,6 @@
 #define STK_INTEGER_H
 
 #include <map>
-#include "STK_String.h"
 
 // for building
 #ifdef IS_RTKPP_LIB
@@ -46,14 +45,6 @@
 
 namespace STK
 {
-/** @ingroup Base
-  *  @brief STK fundamental type of discrete values.
-  *
-  *  The type Integer is defined for the numerical computation and the
-  *  internal representation of the discrete variables.
-  **/
-typedef int Integer ;
-
 /** @ingroup Arithmetic
  *  @brief Specialization for Integer (long).
  *
@@ -61,7 +52,7 @@ typedef int Integer ;
  *  Type for representing NA (not available) discrete numbers.
  */
 template<>
-struct Arithmetic<Integer>  : public std::numeric_limits<Integer>
+struct Arithmetic<Integer>: public std::numeric_limits<Integer>
 {
 #ifdef IS_RTKPP_LIB
   enum
